@@ -11,17 +11,22 @@ API_INSTANCE_HOLDER = {
     KEY_API_INSTANCE: None
 }
 
+KW_PARAMETERS = 'params'
+KW_HEADERS = 'headers'
+
 
 Response = Response
 request = request
 Resource = flask_restful.Resource
 
+@Function
 def safellyGetRequestBody() :
     requestBody = safellyGetJson()
     if ObjectHelper.isNone(requestBody):
         requestBody = safellyGetData()
     return requestBody if ObjectHelper.isNotNone(requestBody) else dict()
 
+@Function
 def safellyGetJson():
     jsonBody = None
     try :
@@ -31,6 +36,7 @@ def safellyGetJson():
         log.log(safellyGetJson, f'Not possible to get request body. Returning {jsonBody} by default', exception=exception)
     return jsonBody
 
+@Function
 def safellyGetResponseJson(response):
     jsonBody = None
     try :
@@ -40,6 +46,7 @@ def safellyGetResponseJson(response):
         log.log(safellyGetResponseJson, f'Not possible to get response body. Returning {jsonBody} by default', exception=exception)
     return jsonBody
 
+@Function
 def safellyGetData():
     dataBody = None
     try :
@@ -49,6 +56,7 @@ def safellyGetData():
         log.log(safellyGetData, f'Not possible to get data. Returning {dataBody} by default', exception=exception)
     return dataBody
 
+@Function
 def safellyGetUrl() :
     url = None
     try :
@@ -57,6 +65,7 @@ def safellyGetUrl() :
         log.log(safellyGetUrl, 'Not possible to get url', exception=exception)
     return url
 
+@Function
 def safellyGetVerb() :
     verb = None
     try :
@@ -65,24 +74,27 @@ def safellyGetVerb() :
         log.log(safellyGetVerb, 'Not possible to get verb', exception=exception)
     return verb
 
+@Function
 def safellyGetHeaders():
     headers = None
     try:
         headers= request.headers
     except Exception as exception :
         headers = {}
-        log.log(safellyGetHeaders, 'Not possible to get request headers. Returning {headers} by default', exception=exception)
+        log.log(safellyGetHeaders, f'Not possible to get request headers. Returning {headers} by default', exception=exception)
     return headers if ObjectHelper.isNotNone(headers) else dict()
 
+@Function
 def safellyGetResponseHeaders(response):
     headers = None
     try:
-        headers= response.headers
+        headers= dict(response.headers)
     except Exception as exception :
         headers = {}
-        log.log(safellyGetResponseHeaders, 'Not possible to get response headers. Returning {headers} by default', exception=exception)
+        log.log(safellyGetResponseHeaders, f'Not possible to get response headers. Returning {headers} by default', exception=exception)
     return headers if ObjectHelper.isNotNone(headers) else dict()
 
+@Function
 def safellyGetArgs():
     args = None
     try:
@@ -92,16 +104,25 @@ def safellyGetArgs():
         log.log(safellyGetArgs, f'Not possible to get args. Returning {args} by default', exception=exception)
     return args if ObjectHelper.isNotNone(args) else dict()
 
+@Function
 def buildHttpResponse(additionalResponseHeaders, controllerResponseBody, status, contentType):
     httpResponse = Response(Serializer.jsonifyIt(controllerResponseBody),  mimetype=contentType, status=status)
     for key, value in additionalResponseHeaders.items():
         httpResponse.headers[key] = value
     return httpResponse
 
+@Function
+def addToKwargs(key, givenClass, valuesAsDictionary, kwargs):
+    if ObjectHelper.isNotEmpty(givenClass):
+        toClass = givenClass if ObjectHelper.isNotList(givenClass) else givenClass[0]
+        kwargs[key] = Serializer.convertFromJsonToObject({k:v for k,v in valuesAsDictionary.items()}, toClass)
+    return valuesAsDictionary
+
 @Function
 def getGlobals() :
     return globals.getGlobalsInstance()
 
+@Function
 def getApi() :
     api = None
     try:
@@ -118,15 +139,19 @@ def getNullableApi() :
         log.warning(getNullableApi, 'Not possible to get api', exception=exception)
     return api
 
+@Function
 def getClassName(instance) :
     return instance.__class__.__name__
 
+@Function
 def getModuleName(instance) :
     return instance.__class__.__module__
 
+@Function
 def getQualitativeName(instance) :
     return instance.__class__.__qualname__
 
+@Function
 def isApiInstance(apiInstance):
     if ObjectHelper.isNone(apiInstance):
         return False
@@ -142,6 +167,7 @@ def validateResourceInstance(resourceInstance) :
     if ObjectHelper.isNone(resourceInstance) :
         raise Exception(f'Resource cannot be None')
 
+@Function
 def retrieveApiInstance(apiInstance=None, arguments=None):
     if isApiInstance(apiInstance):
         return apiInstance
